pitchtools.pentatonic_pitch_number_to_chromatic_pitch_number
============================================================

.. autofunction:: abjad.tools.pitchtools.pentatonic_pitch_number_to_chromatic_pitch_number.pentatonic_pitch_number_to_chromatic_pitch_number
